@@ -2,7 +2,7 @@
 #'
 #' \pkg{lintr} now runs \pkg{cyclocomp}, which we use independently and we don't
 #' want to run it twice. So this is just a wrapper to
-#' code{\link[lintr:lint_package]{lintr::lint_package}} where we hardcode the
+#' \code{\link[lintr:lint_package]{lintr::lint_package}} where we hardcode the
 #' exclusion of unwanted linters (more may be added to \pkg{lintr}) so other
 #' packages using \pkg{packager}'s \file{Makefile} or
 #' \code{\link{get_package_makelist}} don't have to care of changes to the
@@ -14,7 +14,11 @@
 #' @export
 lint_package <- function(path) {
     # We use cyclocomp anyways, plus it takes time..
-    linters <- lintr::linters_with_defaults(cyclocomp_linter = NULL)
+    llwd <- lintr::linters_with_defaults
+    linters <- llwd(cyclocomp_linter = NULL,
+                    lintr::indentation_linter(indent = 4L,
+                                              hanging_indent_style = "always")
+                    )
     lints <- lintr::lint_package(path = path, linters = linters)
     return(lints)
 }
